@@ -11,23 +11,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 import json
-import mock
-from oslo_config import cfg
 import unittest
+from unittest import mock
 
-
+from oslo_config import cfg
 from pyspark.streaming.kafka import OffsetRange
 
-from tests.functional.messaging.adapter import DummyAdapter
-from tests.functional.spark_context_test import SparkContextTest
-from tests.functional.test_resources.cpu_kafka_data.data_provider \
-    import DataProvider
-from tests.functional.test_resources.mock_component_manager \
-    import MockComponentManager
-from tests.functional.test_resources.mock_data_driven_specs_repo \
-    import MockDataDrivenSpecsRepo
-
 from monasca_transform.component.usage.fetch_quantity_util import \
     FetchQuantityUtilException
 from monasca_transform.config.config_initializer import ConfigInitializer
@@ -35,6 +26,14 @@ from monasca_transform.driver.mon_metrics_kafka \
     import MonMetricsKafkaProcessor
 from monasca_transform.transform import RddTransformContext
 from monasca_transform.transform import TransformContextUtils
+from tests.functional.messaging.adapter import DummyAdapter
+from tests.functional.spark_context_test import SparkContextTest
+from tests.functional.test_resources.cpu_kafka_data.data_provider \
+    import DataProvider
+from tests.functional.test_resources.mock_component_manager \
+    import MockComponentManager
+from tests.functional.test_resources.mock_data_driven_specs_repo \
+    import MockDataDrivenSpecsRepo
 
 
 class TestFetchQuantityUtilAgg(SparkContextTest):
@@ -59,15 +58,13 @@ class TestFetchQuantityUtilAgg(SparkContextTest):
                                     "set_default_region_to":"W"},
          "event_type":"cpu.total_logical_cores",
          "metric_id_list":["cpu_util_all"],
-         "required_raw_fields_list":["creation_time"],
-         "service_id":"host_metrics"}""", """
+         "required_raw_fields_list":["creation_time"]}""", """
         {"event_processing_params":{"set_default_zone_to":"1",
                                     "set_default_geolocation_to":"1",
                                     "set_default_region_to":"W"},
          "event_type":"cpu.idle_perc",
          "metric_id_list":["cpu_util_all"],
-         "required_raw_fields_list":["creation_time"],
-         "service_id":"host_metrics"}"""]
+         "required_raw_fields_list":["creation_time"]}"""]
         pre_transform_specs_json_list = \
             [json.loads(pre_transform_spec)
              for pre_transform_spec in pre_transform_specs]
